@@ -82,8 +82,21 @@ class PyCTPP2Settings():
         self.path.append(path)
 
 
+def _find_all_gettext_files(domain, folder):
+    """Find .mo files in folder"""
+    langs = [n for n in os.listdir(folder) if os.path.isdir(os.path.join(folder, n))]
+
+    for lang in langs:
+        fullpath = os.path.join(folder, lang, 'LC_MESSAGES')
+        if not os.path.exists(fullpath):
+            continue
+        for n in os.listdir(fullpath):
+            if n.endswith('.mo') and os.path.basename(n)[:-3] == domain:
+                yield (lang, os.path.join(fullpath, n))
+
+
 class PyCTPP2TemplateRenderer(object):
-    '''Renderer for a pyctpp2 template'''
+    """Renderer for a pyctpp2 template"""
     implements(ITemplateRenderer)
 
     template = None
@@ -109,7 +122,8 @@ class PyCTPP2TemplateRenderer(object):
             folder = info.settings.get('pyctpp2.i18n.path', '')
             if folder:
                 folder = abspath_from_asset_spec(folder)
-                self.engine.add_translation(domain, folder)
+                for lang, fpath in _find_all_gettext_files(domain, folder):
+                    self.engine.add_translation(fpath, domain, lang)
 
 
     def implementation(self):
@@ -135,7 +149,8 @@ class PyCTPP2TemplateRenderer(object):
 
         for domain, folder in self.tmpl_settings.locales.items():
             folder = abspath_from_asset_spec(folder)
-            self.engine.add_translation(domain, folder)
+            for lang, fpath in _find_all_gettext_files(domain, folder):
+                self.engine.add_translation(fpath, domain, lang)
 
         isabs = os.path.isabs(self.info.name)
 
@@ -164,7 +179,7 @@ class PyCTPP2TemplateRenderer(object):
             loc = loc.encode('UTF-8')
             value['LOCALE_'] = loc
 
-        return self.template.render(value, locale=loc)
+        return self.template.render(value, language=loc)
 
 def includeme(config):
     '''Setup standard configurator registrations.'''
